@@ -34,6 +34,7 @@ from __future__ import with_statement
 from django.test import TestCase
 
 from permission.backends import RoleBackend
+from permission.utils import permission_to_perm
 from permission.tests import create_user
 from permission.tests import create_role
 from permission.tests import create_permission
@@ -109,6 +110,13 @@ class PermissionRoleBackendTestCase(TestCase):
         role1, role2, role3 = self.role1, self.role2, self.role3
         role4, role5, role6 = self.role4, self.role5, self.role6
 
+        role1 = role1.codename
+        role2 = role2.codename
+        role3 = role3.codename
+        role4 = role4.codename
+        role5 = role5.codename
+        role6 = role6.codename
+
         self.assertItemsEqual(backend.get_all_roles(user1), [
                 role1,
             ])
@@ -142,6 +150,15 @@ class PermissionRoleBackendTestCase(TestCase):
         perm1, perm2, perm3, perm4 = self.perm1, self.perm2, self.perm3, self.perm4
         perm5, perm6, perm7, perm8 = self.perm5, self.perm6, self.perm7, self.perm8
 
+        perm1 = permission_to_perm(perm1)
+        perm2 = permission_to_perm(perm2)
+        perm3 = permission_to_perm(perm3)
+        perm4 = permission_to_perm(perm4)
+        perm5 = permission_to_perm(perm5)
+        perm6 = permission_to_perm(perm6)
+        perm7 = permission_to_perm(perm7)
+        perm8 = permission_to_perm(perm8)
+
         self.assertItemsEqual(backend.get_all_permissions(user1), [
                 perm1, perm2,
             ])
